This is the script to filter drone route from .log and .txt file to .csv file

Install
pip install avirtech_route_drone_filter

Usage
from avirtech_route_drone_filter.route_drone_filter import filter_drone_route